@@ -17,8 +17,7 @@ private:
 
 
   unsigned long messageSize;
-  enum { max_length = 16384 };
-  char data[max_length];
+  char data[maxMessageIOSize];
 
   void handleResolve(const asio::error_code& err, asio::ip::tcp::resolver::iterator endpoint_iterator);
   void handleConnect(const asio::error_code& err, asio::ip::tcp::resolver::iterator endpoint_iterator);
