@@ -5,15 +5,16 @@
 #include <string>
 #include <boost/noncopyable.hpp>
 #include "tcpmessageserverconnection.h"
-#include "messageserver.h"
 
 
-class TCPMessageServer : private boost::noncopyable, public MessageServer
+class TCPMessageServer : private boost::noncopyable
 {
 private:
   asio::io_service & ioservice;
   asio::ip::tcp::acceptor acceptor;
 
+  ServerConnectorFactoryBase & serverConnectorFactoryBase;
+
   void handleAccept(const asio::error_code& e);
   void handleStop();
 
@@ -22,7 +23,7 @@ private:
   connection_ptr newConnection;
 
 public:
-  explicit TCPMessageServer(asio::io_service& io_service, const asio::ip::tcp::endpoint & endpoint);
+  explicit TCPMessageServer(asio::io_service& io_service, const asio::ip::tcp::endpoint & endpoint, ServerConnectorFactoryBase & serverConnectorFactoryBase);
 
   void run();
 
