@@ -6,7 +6,12 @@
 #include <string>
 #include <asio.hpp>
 #include <boost/array.hpp>
+#ifdef HAVE_CURSES_H
 #include <curses.h>
+#endif
+#ifdef HAVE_NCURSES_H
+#include <ncurses.h>
+#endif
 #include "sinfodata.h"
 #include "sinfoviewconfig.h"
 
