@@ -9,7 +9,7 @@
 class BroadcastReceiver
 {
 private:
-  enum { max_length = 2048 };
+  enum { max_length = 65535 }; // maximum UDP packet size
   char data[max_length];
   asio::ip::udp::endpoint sender_endpoint;
 
